#ifndef configDialog_H
#define configDialog_H

#include <qvariant.h>
#include <qdialog.h>
#include <qhbox.h> 
#include <qlayout.h>

class QButtonGroup;
class QPushButton;
class QWidgetStack;
class QWidget;
class QCheckBox;
class QComboBox;
class QSpinBox;
class QListBox;
class QLabel;
class ColorButton;
	
class configDialog : public QDialog
{
    Q_OBJECT

public:
    configDialog( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~configDialog();

	void initPlotsPage();
	void initAppPage();
	void initCurvesPage();
	void initPlots3DPage();
	void initTablesPage();

	QPushButton *btnBackground3D, *btnMesh, *btnAxes, *btnLabels, *btnNumbers;
	QPushButton *btnFromColor, *btnToColor, *btnGrid;
	QPushButton	*btnTitleFnt, *btnLabelsFnt, *btnNumFnt;

	ColorButton *buttonBackground, *buttonText, *buttonHeader;
    QPushButton *buttonOk, *buttonCancel, *buttonApply;
	QPushButton* buttonTextFont, *buttonHeaderFont;
    QButtonGroup* GroupBox1, *GroupBox2, *GroupBox3;
    QWidgetStack* generalDialog;
	QWidget *tables, *plots, *confirm, *application, *curves, *plots3D;
	QPushButton* buttonAxesFont, *buttonNumbersFont, *buttonLegendFont, *buttonTitleFont, *fontsBtn;
	QCheckBox* boxTitle, *boxFrame, *boxPlots3D, *boxPlots2D, *boxTables;
	QCheckBox *boxSave, *boxBackbones, *boxAllAxes, *boxShowLegend, *boxSmoothMesh;
	QCheckBox *boxAutoscaling, *boxShowProjection, *boxMatrixes, *boxScaleFonts, *boxResize;
	QComboBox *boxLegend, *boxTicks, *boxStyle, *boxCurveStyle, *boxSeparator;
	QSpinBox *boxMinutes, *boxLinewidth, *boxFrameWidth, *boxResolution, *boxMargin;
	QSpinBox *boxCurveLineWidth, *boxSymbolSize, *boxMinorTicks, *boxMajorTicks;
	ColorButton *btnWorkspace, *btnPanels, *btnPanelsText;
	QListBox *itemsList;
	QLabel *labelFrameWidth;

public slots:
    virtual void languageChange();
	void accept();
	void update();

	void setColumnSeparator(const QString& sep);
	//table colors
	void pickBgColor();
	void pickTextColor();
	void pickHeaderColor();
	void initColors(const QColor& bgCol, const QColor& textCol, const QColor& headerCol);

	//table fonts
	void pickTextFont();
	void pickHeaderFont();
	void initFonts(const QFont& textFnt, const QFont& headerFnt);

	//graph fonts
	void pickAxesFont();
	void pickNumbersFont();
	void pickLegendFont();
	void pickTitleFont();
	void initGraphFonts(const QFont& axesFnt, const QFont& numbersFnt, 
										const QFont& legendFnt, const QFont& titleFnt);

	void initPlotOptions(int ticksStyle, int legendStyle, bool titleOn, bool allAxes, bool frameOn,
						 int frameWidth, bool backbones, int axeLineWidth, int minLength, 
						 int majLength, int margin, bool autoscale, bool scaleFonts, 
						 bool resizeLayers);
	void enableScaleFonts();

	void initConfirmOptions(bool askTables, bool askMatrixes, 
							bool askPlots2D, bool askPlots3D);
	int ticksType();
	void showFrameWidth(bool ok);

	//application
	void pickApplicationFont();
	void initAppFonts(const QFont& fnt);
	void initAppStyle(const QString& s);
	void initSaveSettings(bool autoSave, int min);
	void pickPanelsTextColor();
	void pickPanelsColor();
	void pickWorkspaceColor();
	void initAppColors(const QColor& wCol, const QColor& pCol, const QColor& tCol);
	
	//2D curves
	int curveStyle();
	void initCurvesOptions(int style, int width, int symbolSize);

	//3D plots
	void initPlot3DOptions(const QStringList& lst, bool legend, 
						  bool projection, bool smooth, int resolution, 
						  const QFont& titleFnt,const QFont& numbersFnt, 
						  const QFont& axesFnt);

	void pickDataMaxColor();
	void pickDataMinColor();
	void pick3DBackgroundColor();
	void pickMeshColor();
	void pickGridColor();
	void pick3DAxesColor();
	void pick3DNumbersColor();
	void pick3DLabelsColor();
	void pick3DTitleFont();
	void pick3DNumbersFont();
	void pick3DAxesFont();

private:
	QFont textFont, headerFont, axesFont, numbersFont, legendFont, titleFont, appFont;
	QFont plot3DTitleFont, plot3DNumbersFont, plot3DAxesFont;
	QStringList plot3DColors;
};

#endif // configDialog_H
